==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Input/wildmidi/translations/wildmidi_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="50"/>
        <source>WildMidi Plugin</source>
        <translation>Plugin WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="55"/>
        <source>Midi Files</source>
        <translation>File Midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="107"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>Tentang Plugin Audio WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="108"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>Plugin Audio WildMidi Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="109"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>Plugin ini menggunakan pustaka WildMidi untuk memainkan file midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="110"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation>Setelan Plugin WildMidi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation>Konfigurasi instrumen: </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="43"/>
        <source>Sample rate:</source>
        <translation>Sample rate:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="50"/>
        <source>Enhanced resampling</source>
        <translation>Resampling canggih</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Reverberation</source>
        <translation>Gema</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Input/wildmidi/translations/wildmidi_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="50"/>
        <source>WildMidi Plugin</source>
        <translation>Plugin WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="55"/>
        <source>Midi Files</source>
        <translation>File Midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="109"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>Tentang Plugin Audio WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="110"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>Plugin Audio WildMidi Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="111"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>Plugin ini menggunakan pustaka WildMidi untuk memainkan file midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="112"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation>Setelan Plugin WildMidi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation>Konfigurasi instrumen: </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="43"/>
        <source>Sample rate:</source>
        <translation>Sample rate:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="50"/>
        <source>Enhanced resampling</source>
        <translation>Resampling canggih</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Reverberation</source>
        <translation>Gema</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
</context>
</TS>
